==> linshare-1.4.6-src.tar.bz2: src/main/java/org/linagora/linshare/core/domain/vo/DomainPolicyVo.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2013 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2013. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.domain.vo;

import org.apache.tapestry5.beaneditor.Validate;
import org.linagora.linshare.core.domain.entities.DomainPolicy;

public class DomainPolicyVo {

	private String identifier;
	private String policyDescription;
	private DomainAccessPolicyVo domainAccessPolicy;

	public DomainPolicyVo() {
	}

	public DomainPolicyVo(DomainPolicy policy) {

		this.identifier = policy.getIdentifier();
		this.policyDescription = policy.getDescription();
		this.domainAccessPolicy = new DomainAccessPolicyVo(policy.getDomainAccessPolicy());
	}

	public DomainPolicyVo(String identifier, String description) {

		this.identifier = identifier;
		this.policyDescription = description;
		this.domainAccessPolicy = null;
	}

	@Validate("required")
	public String getIdentifier() {
		return identifier;
	}

	public void setIdentifier(String identifier) {
		if (identifier != null)
			this.identifier = identifier.trim();
		else
			this.identifier = identifier;
	}

	public String getPolicyDescription() {
		return policyDescription;
	}

	public void setPolicyDescription(String description) {
		if (description != null)
			this.policyDescription = description.trim();
		else
			this.policyDescription = description;
	}

	public DomainAccessPolicyVo getDomainAccessPolicy() {
		return domainAccessPolicy;
	}

	public void setDomainAccessPolicy(DomainAccessPolicyVo domainAccessPolicy) {
		this.domainAccessPolicy = domainAccessPolicy;
	}

}

==> linshare-1.5.1-src.tar.bz2: src/main/java/org/linagora/linshare/core/domain/vo/DomainPolicyVo.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2013 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2013. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.domain.vo;

import java.io.Serializable;

import org.apache.tapestry5.beaneditor.Validate;
import org.linagora.linshare.core.domain.entities.DomainPolicy;

public class DomainPolicyVo implements Serializable {

	private static final long serialVersionUID = 7427538327433681513L;
	private String identifier;
	private String policyDescription;
	private DomainAccessPolicyVo domainAccessPolicy;

	public DomainPolicyVo() {
	}

	public DomainPolicyVo(DomainPolicy policy) {

		this.identifier = policy.getIdentifier();
		this.policyDescription = policy.getDescription();
		this.domainAccessPolicy = new DomainAccessPolicyVo(policy.getDomainAccessPolicy());
	}

	public DomainPolicyVo(String identifier, String description) {

		this.identifier = identifier;
		this.policyDescription = description;
		this.domainAccessPolicy = null;
	}

	@Validate("required")
	public String getIdentifier() {
		return identifier;
	}

	public void setIdentifier(String identifier) {
		if (identifier != null)
			this.identifier = identifier.trim();
		else
			this.identifier = identifier;
	}

	public String getPolicyDescription() {
		return policyDescription;
	}

	public void setPolicyDescription(String description) {
		if (description != null)
			this.policyDescription = description.trim();
		else
			this.policyDescription = description;
	}

	public DomainAccessPolicyVo getDomainAccessPolicy() {
		return domainAccessPolicy;
	}

	public void setDomainAccessPolicy(DomainAccessPolicyVo domainAccessPolicy) {
		this.domainAccessPolicy = domainAccessPolicy;
	}

}
